# HitchChrome

HitchChrome is a way of downloading and installing a version
of Chrome that will work with selenium that is kept separate
from your system packages.

## Why?

* Ubuntu/Debian aren't very good at ensuring chromedriver/chrome versions are kept in sync.
* You can "freeze" the version of chrome available this way, and avoid indeterminacy in your tests.
